@@ -36,11 +36,12 @@ class StringFunction:
 
 
 def converttobs(strvar):
-    x = stringfunction()
+    x = StringFunction()
     x.text = strvar
     return x
 
-def converttostr(stringfunctionvar: stringfunction):
+
+def converttostr(stringfunctionvar: StringFunction):
     x = stringfunctionvar.text
     return x
 
